<?php

namespace Modules\Am\Http\Controllers;

use Exception;
use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Illuminate\Support\Facades\DB;
use Modules\Am\Entities\Department;
use Modules\Am\Entities\Designation;
use Modules\Am\Entities\Employee;
use Modules\Am\Http\common\commonFeatures;

class EmployeeController extends Controller
{
   use commonFeatures;

    public function allDepartment_Designation()
    {
        try {
            $departments = Department::all();
            $designations = Designation::all();
            $response =  $this->responseBody(true, "Location", "allLocation", ['departments' => $departments, 'designations' => $designations]);
        } catch (Exception $exception) {
            $response =  $this->responseBody(false, "Location", "allLocation", $exception);
        }
        return $response;
    }



    public function all()
    {
        try {
            $employees = DB::select('SELECT am_employee.id AS thID,am_employee.CompanyID AS thEmployeeID,am_employee.`Name` AS thName,
            am_employee.NIC AS thNIC,am_employee.Email AS thEmail,am_employee.PhoneNumber AS thPhone,am_employee.ApprovalAuthority AS thAuthority,am_department.`Name` AS thDepartment,am_designation.`Name` AS thDesignation FROM am_employee LEFT JOIN am_designation ON am_employee.DesignationID = am_designation.id
            LEFT JOIN am_department ON am_employee.DepartmentID = am_department.id');
            foreach ($employees as $employee) {
                if ($employee->thAuthority == 1) {
                    $employee->thAuthority = '<label class="badge badge-success">Yes</label>';
                } else {
                    $employee->thAuthority = '<label class="badge badge-danger">NO</label>';
                }
                $employee->thEdit =  '<button type="button" class="btn btn-primary"  onclick="edit(' . $employee->thID . ')"><i class="fa fa-pencil-square-o" aria-hidden="true"></i></button>';
                $employee->thDelete = '<button type="button" class="btn btn-danger" onclick="_delete(' . $employee->thID . ')"><i class="fa fa-trash" aria-hidden="true"></i></button>';
            }
            $response =  $this->responseBody(true, "Employee", "all", $employees);
        } catch (Exception $exception) {
            $response =  $this->responseBody(false, "Employee", "all", $exception);
        }
        return $response;
    }


    public function get($id)
    {
        try {
            $employee = Employee::find($id);
            $response =  $this->responseBody(true, "Employee", "get", $employee);
        } catch (Exception $exception) {
            $response =  $this->responseBody(false, "Employee", "get", $exception);
        }
        return $response;
    }




    public function save(Request $request)
    {
        try {

            $employee = new Employee();
            $employee->CompanyID = $request->get('id');
            $employee->Name = $request->get('name');
            $employee->NIC = $request->get('nic');
            $employee->Email = $request->get('email');
            $employee->PhoneNumber = $request->get('phone');
            $employee->DesignationID = $request->get('designation');
            $employee->DepartmentID = $request->get('department');
            if ($request->get('yes') == 'false') {
                $employee->ApprovalAuthority = 0;
            } else {
                $employee->ApprovalAuthority = 1;
            }
            $employee->Status = 1;
            if ($employee->save()) {
                $response =  $this->responseBody(true, "Employee", "save", null);
            } else {
                $response =  $this->responseBody(false, "Employee", "save", "");
            }
        } catch (Exception $exception) {
            $response =  $this->responseBody(false, "Employee", "save", $exception);
        }
        return $response;
    }




    public function update(Request $request, $id)
    {
        try {

            $employee = Employee::find($id);
            $employee->CompanyID = $request->get('id');
            $employee->Name = $request->get('name');
            $employee->NIC = $request->get('nic');
            $employee->Email = $request->get('email');
            $employee->PhoneNumber = $request->get('phone');
            $employee->DesignationID = $request->get('designation');
            $employee->DepartmentID = $request->get('department');
            if ($request->get('yes') == "false") {
                $employee->ApprovalAuthority = 0;
            } else {
                $employee->ApprovalAuthority = 1;
            }
            $employee->Status = 1;
            if ($employee->update()) {
                $response =  $this->responseBody(true, "Employee", "update", null);
            } else {
                $response =  $this->responseBody(false, "Employee", "update", "");
            }
        } catch (Exception $exception) {
            $response =  $this->responseBody(false, "Employee", "update", $exception);
        }
        return $response;
    }




    public function delete($id)
    {
        try {

            $employee = Employee::find($id);
            if ($employee->delete()) {
                $response =  $this->responseBody(true, "Employee", "delete", null);
            } else {
                $response =  $this->responseBody(false, "Employee", "delete", "");
            }
        } catch (Exception $exception) {
            $response =  $this->responseBody(false, "Employee", "delete", $exception);
        }
        return $response;
    }

}
